<?php

namespace Drupal\trash\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;

class TrashDeleteController extends ControllerBase {

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EntityController.
   *
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(RouteMatchInterface $route_match, EntityTypeManagerInterface $entity_type_manager) {
    $this->routeMatch = $route_match;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_route_match'),
      $container->get('entity_type.manager')
    );
  }

  public function entityDelete() {
    $parameters = $this->routeMatch->getParameters();
    foreach ($parameters as $entity_type_id => $entity_id) {
      $storage = $this->entityTypeManager->getStorage($entity_type_id);
      $entity = $storage->load($entity_id);
      if (empty($entity)) {
        drupal_set_message(t('Unable to load entity.'), 'error');
        return $this->redirect('<front>');
      }
      drupal_set_message(t('The @entity %label has been moved to the trash.', ['@entity' => $entity->getEntityType()->get('label'), '%label' => $entity->label()]));
      $entity->delete();
    }
    return $this->redirect($this->getRedirectUrl($entity)->getRouteName(),$this->getRedirectUrl($entity)->getRouteParameters());
  }

  /**
   * @param ContentEntityInterface $entity
   *
   * @return \Drupal\Core\Url
   */
  protected function getRedirectUrl(ContentEntityInterface $entity) {
    if ($entity->hasLinkTemplate('collection')) {
      // If available, return the collection URL.
      return $entity->toUrl('collection');
    }
    else {
      // Otherwise fall back to the front page.
      return Url::fromRoute('<front>');
    }
  }

}
